@@ -3,15 +3,21 @@
 
 import asyncio
 import fleet as flt
+from dotenv import load_dotenv
+
+load_dotenv()
 
 
 async def main():
+    regions = await flt.env.list_regions_async()
+    print("Regions:", regions)
+
     environments = await flt.env.list_envs_async()
     print("Environments:", len(environments))
 
     # Create a new instance
     env = await flt.env.make_async("hubspot:v1.2.7")
-    print("New Instance:", env.instance_id)
+    print(f"New Instance: {env.instance_id} ({env.region})")
 
     response = await env.reset(seed=42)
     print("Reset response:", response)
