@@ -29,6 +29,8 @@ from .instance import (
     ValidatorType,
     ExecuteFunctionResponse,
 )
+from .config import DEFAULT_MAX_RETRIES, REGION_BASE_URL
+from .instance.base import default_httpx_client
 from .resources.base import Resource
 from .resources.sqlite import AsyncSQLiteResource
 from .resources.browser import AsyncBrowserResource
@@ -37,15 +39,17 @@ logger = logging.getLogger(__name__)
 
 
 class AsyncEnvironment(EnvironmentBase):
-    def __init__(self, httpx_client: Optional[httpx.AsyncClient] = None, **kwargs):
+    def __init__(self, client: AsyncWrapper, **kwargs):
         super().__init__(**kwargs)
-        self._httpx_client = httpx_client or httpx.AsyncClient(timeout=180.0)
+        self._client = client
         self._instance: Optional[AsyncInstanceClient] = None
 
     @property
     def instance(self) -> AsyncInstanceClient:
         if self._instance is None:
-            self._instance = AsyncInstanceClient(self.manager_url, self._httpx_client)
+            self._instance = AsyncInstanceClient(
+                self.manager_url, self._client.httpx_client
+            )
         return self._instance
 
     async def reset(
@@ -66,7 +70,10 @@ class AsyncEnvironment(EnvironmentBase):
         return await self.instance.resources()
 
     async def close(self) -> InstanceRecord:
-        return await AsyncFleet().delete(self.instance_id)
+        response = await self._client.request(
+            "DELETE", f"/v1/env/instances/{self.instance_id}"
+        )
+        return InstanceRecord(**response.json())
 
     async def verify(self, validator: ValidatorType) -> ExecuteFunctionResponse:
         return await self.instance.verify(validator)
@@ -83,8 +90,9 @@ class AsyncFleet:
         api_key: Optional[str] = os.getenv("FLEET_API_KEY"),
         base_url: Optional[str] = None,
         httpx_client: Optional[httpx.AsyncClient] = None,
+        max_retries: int = DEFAULT_MAX_RETRIES,
     ):
-        self._httpx_client = httpx_client or httpx.AsyncClient(timeout=180.0)
+        self._httpx_client = httpx_client or default_httpx_client(max_retries)
         self.client = AsyncWrapper(
             api_key=api_key,
             base_url=base_url,
@@ -115,10 +123,14 @@ class AsyncFleet:
             version = None
 
         request = InstanceRequest(env_key=env_key_part, version=version, region=region)
+        region_base_url = REGION_BASE_URL.get(region)
         response = await self.client.request(
-            "POST", "/v1/env/instances", json=request.model_dump()
+            "POST",
+            "/v1/env/instances",
+            json=request.model_dump(),
+            base_url=region_base_url,
         )
-        instance = AsyncEnvironment(**response.json())
+        instance = AsyncEnvironment(client=self.client, **response.json())
         await instance.instance.load()
         return instance
 
@@ -132,11 +144,14 @@ class AsyncFleet:
             params["region"] = region
 
         response = await self.client.request("GET", "/v1/env/instances", params=params)
-        return [AsyncEnvironment(**instance_data) for instance_data in response.json()]
+        return [
+            AsyncEnvironment(client=self.client, **instance_data)
+            for instance_data in response.json()
+        ]
 
     async def instance(self, instance_id: str) -> AsyncEnvironment:
         response = await self.client.request("GET", f"/v1/env/instances/{instance_id}")
-        instance = AsyncEnvironment(**response.json())
+        instance = AsyncEnvironment(client=self.client, **response.json())
         await instance.instance.load()
         return instance
 
